@@ -19,8 +19,11 @@ import puke.FileSystem
 
 
 VERSION = 0.1
+__all__ = [
+            "main", "VERSION", "Error", "FileList", "Sed", "console", "Env", "Require", "Yak", "VirtualEnv", "System", "FileSystem",
+            "combine", "sh", "minify", "jslint", "jsdoc", "patch", "prompt", "deepcopy", "stats", "pack", "unpack", "hsizeof"
+         ]
 
-__all__ = ["main", "VERSION"]
 
 import sys, logging, os, traceback
 import pkg_resources
